pub struct ChildCleanup {
pub status: Option<ExitStatus>,
pub errors: Vec<String>,
}Expand description
Outcome of a bounded child cleanup attempt.
Fields
status: Option<ExitStatus>Reaped child status, when it became available within the cleanup budget.
errors: Vec<String>Cleanup diagnostics that should be attached to the caller’s error.